Coverage report

File | class |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | --- | ---
savcfg / __init__.py | (no class) |  | 2 | 0 | 0 |  | 100%
savcfg / bootstrap.py | (no class) |  | 29 | 0 | 0 |  | 100%
savcfg / core.py | Group |  | 41 | 24 | 0 |  | 41%
savcfg / core.py | (no class) |  | 11 | 0 | 0 |  | 100%
savcfg / edit.py | VarsEditor |  | 0 | 0 | 3 |  | 100%
savcfg / edit.py | ConfigEditor |  | 8 | 0 | 0 |  | 100%
savcfg / edit.py | (no class) |  | 9 | 0 | 7 |  | 100%
savcfg / keyvault.py | KeyVaultVars |  | 23 | 1 | 0 |  | 96%
savcfg / keyvault.py | (no class) |  | 11 | 0 | 0 |  | 100%
savcfg / read.py | VarsReader |  | 0 | 0 | 0 |  | 100%
savcfg / read.py | VariableNotFound |  | 2 | 0 | 0 |  | 100%
savcfg / read.py | ConfigService |  | 30 | 5 | 0 |  | 83%
savcfg / read.py | (no class) |  | 16 | 0 | 0 |  | 100%
Total |  |  | 182 | 30 | 10 |  | 84%

No items found using the specified filter.